@@ -31,6 +31,7 @@ define!({
         Value(Value),
         DeclarationBlockItem(DeclarationBlockItem),
         Rule(Rule),
+        StyleBlock(StyleBlock),
     }
 
     pub struct Ident {
@@ -86,6 +87,13 @@ define!({
         pub block: SimpleBlock,
     }
 
+    pub enum StyleBlock {
+        AtRule(AtRule),
+        Declaration(Declaration),
+        QualifiedRule(QualifiedRule),
+        Invalid(Tokens),
+    }
+
     pub enum DeclarationBlockItem {
         Invalid(Tokens),
         Declaration(Declaration),
@@ -430,6 +438,7 @@ define!({
         Page(PageRule),
         PageMargin(PageMarginRule),
         Namespace(NamespaceRule),
+        Nest(NestRule),
         Viewport(ViewportRule),
         Document(DocumentRule),
         ColorProfile(ColorProfileRule),
@@ -482,6 +491,12 @@ define!({
         pub uri: NamespaceUri,
     }
 
+    pub struct NestRule {
+        pub span: Span,
+        pub prelude: SelectorList,
+        pub block: SimpleBlock,
+    }
+
     pub struct ViewportRule {
         pub span: Span,
         pub block: SimpleBlock,
@@ -550,13 +565,13 @@ define!({
     pub struct LayerRule {
         pub span: Span,
         pub prelude: Option<LayerPrelude>,
-        pub rules: Option<Vec<Rule>>,
+        pub block: Option<SimpleBlock>,
     }
 
     pub struct MediaRule {
         pub span: Span,
         pub media: Option<MediaQueryList>,
-        pub rules: Vec<Rule>,
+        pub block: SimpleBlock,
     }
 
     pub struct MediaQueryList {
@@ -700,7 +715,7 @@ define!({
     pub struct SupportsRule {
         pub span: Span,
         pub condition: SupportsCondition,
-        pub rules: Vec<Rule>,
+        pub block: SimpleBlock,
     }
 
     pub struct SupportsCondition {
